/*
 * Copyright (c) 2013-2017 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel', {
  extend : 'Ext.tree.Panel',

  requires : [
    'QDesk.Msg',
    'QDesk.enums.message.MessageChannel',
    'QDesk.enums.security.Permission',
    'QDesk.store.message.MessageChannelProfilesTreeStore',
    'QDesk.util.EnumUtils',
    'QDesk.util.constant.Const'
  ],

  alias : 'widget.MessageChannelProfilesTreePanel',

  cls : 'messageChannelProfilesTreePanel',

  //scrollable : true,

  displayField : 'name',

  rootVisible : true,

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      root : {
        id : QDesk.util.constant.Const.MESSAGE_CHANNEL_PROFILES_ROOT_ID,  // ROOT folder ID
        folderId : QDesk.util.constant.Const.MESSAGE_CHANNEL_PROFILES_ROOT_FOLDER_ID,
        name : QDesk.Msg.get( 'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.rootNodeName' ),
        expanded : true,

        /* MessageChannelProfilesTreeNode */
        nodeType : 'folder'
      },

      viewConfig : {
        copy : false,

        plugins : {
          ptype : 'treeviewdragdrop',
          appendOnly : true,
          dragText : QDesk.Msg.get( 'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.dragText' )
        }
      },

      store : Ext.create( 'QDesk.store.message.MessageChannelProfilesTreeStore' ),

      dockedItems : [
        {
          xtype : 'toolbar',
          itemId : 'toolBar',
          dock : 'top',
          items : [
            {
              xtype : 'button',
              itemId : 'refreshButton',
              scale : 'small',
              iconCls : 'refresh',
              tooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.tooltipRefreshButton' ),
              disabled : true,
              qdRequiresAnyPermissions : [],
              qdNotAuthorizedIconCls : 'refreshNAUTH'
            },
            {
              xtype : 'button',
              itemId : 'collapseAllButton',
              scale : 'small',
              iconCls : 'collapseAll',
              tooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.tooltipCollapseAllButton' ),
              disabled : true
            },
            '-',
            {
              xtype : 'button',
              itemId : 'addFolderOrProfileButton',
              scale : 'small',
              iconCls : 'addFolderOrProfile',
              tooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.tooltipAddFolderOrProfileButton' ),
              disabled : true,
              qdRequiresAnyPermissions : [
                QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_FLD_ADD,
                QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD
              ],
              qdNotAuthorizedIconCls : 'addFolderOrProfileNAUTH',
              menu : {
                xtype : 'menu',
                ignoreParentClicks : true,
                items : [
                  {
                    itemId : 'addFolderButton',
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addFolderButton' ),
                    iconCls : 'addFolder',
                    qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_FLD_ADD ],
                    qdNotAuthorizedIconCls : 'addFolderNAUTH'
                  },
                  '-',
                  {
                    itemId : 'addEmailProfileButton',
                    text : QDesk.util.EnumUtils.getMessageChannelName(
                        QDesk.enums.message.MessageChannel.EMAIL ),
                    iconCls : QDesk.enums.message.MessageChannel.EMAIL,
                    qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                    qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.EMAIL + '_NAUTH'
                  },

                  /*
                   * Collaboration message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addCollaborationProfileGroup' ),
                    iconCls : 'addCollaborationProfile',
                    menu : [
                      {
                        itemId : 'addCollaborationHipChatProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.COLLABORATION_HIPCHAT ),
                        iconCls : QDesk.enums.message.MessageChannel.COLLABORATION_HIPCHAT,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.COLLABORATION_HIPCHAT + '_NAUTH'
                      },
                      {
                        itemId : 'addCollaborationSlackProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.COLLABORATION_SLACK ),
                        iconCls : QDesk.enums.message.MessageChannel.COLLABORATION_SLACK,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.COLLABORATION_SLACK + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * Instant message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addInstantMessageProfileGroup' ),
                    iconCls : 'addInstantMessageProfile',
                    menu : [
                      {
                        itemId : 'addImAimProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.IM_AIM ),
                        iconCls : QDesk.enums.message.MessageChannel.IM_AIM,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.IM_AIM + '_NAUTH'
                      },
                      {
                        itemId : 'addImGTalkProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.IM_GTALK ),
                        iconCls : QDesk.enums.message.MessageChannel.IM_GTALK,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.IM_GTALK + '_NAUTH'
                      },
                      {
                        itemId : 'addImIcqProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.IM_ICQ ),
                        iconCls : QDesk.enums.message.MessageChannel.IM_ICQ,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.IM_ICQ + '_NAUTH'
                      },
                      {
                        itemId : 'addImXmppProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.IM_XMPP ),
                        iconCls : QDesk.enums.message.MessageChannel.IM_XMPP,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.IM_XMPP + '_NAUTH'
                      },
                      {
                        itemId : 'addImYahooProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.IM_YAHOO ),
                        iconCls : QDesk.enums.message.MessageChannel.IM_YAHOO,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.IM_YAHOO + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * SMS message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addSmsProfileGroup' ),
                    iconCls : 'addSmsProfile',
                    menu : [
                      {
                        itemId : 'addSmsClickatellCentralProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SMS_CLICKATELL_CENTRAL ),
                        iconCls : QDesk.enums.message.MessageChannel.SMS_CLICKATELL_CENTRAL,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SMS_CLICKATELL_CENTRAL + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsClickatellPlatformProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SMS_CLICKATELL_PLATFORM ),
                        iconCls : QDesk.enums.message.MessageChannel.SMS_CLICKATELL_PLATFORM,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SMS_CLICKATELL_PLATFORM + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsClockworkProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SMS_CLOCKWORK ),
                        iconCls : QDesk.enums.message.MessageChannel.SMS_CLOCKWORK,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SMS_CLOCKWORK + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsNexmoProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SMS_NEXMO ),
                        iconCls : QDesk.enums.message.MessageChannel.SMS_NEXMO,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SMS_NEXMO + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsSmsGlobalProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SMS_SMSGLOBAL ),
                        iconCls : QDesk.enums.message.MessageChannel.SMS_SMSGLOBAL,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SMS_SMSGLOBAL + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsTwilioProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SMS_TWILIO ),
                        iconCls : QDesk.enums.message.MessageChannel.SMS_TWILIO,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SMS_TWILIO + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * SNMP trap message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addSnmpProfileGroup' ),
                    iconCls : 'addSnmpProfile',
                    menu : [
                      {
                        itemId : 'addSnmpV1TrapProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SNMPV1_TRAP ),
                        iconCls : QDesk.enums.message.MessageChannel.SNMPV1_TRAP,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SNMPV1_TRAP + '_NAUTH'
                      },
                      {
                        itemId : 'addSnmpV2cTrapProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SNMPV2C_TRAP ),
                        iconCls : QDesk.enums.message.MessageChannel.SNMPV2C_TRAP,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SNMPV2C_TRAP + '_NAUTH'
                      },
                      {
                        itemId : 'addSnmpV3TrapProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.enums.message.MessageChannel.SNMPV3_TRAP ),
                        iconCls : QDesk.enums.message.MessageChannel.SNMPV3_TRAP,
                        qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.SNMPV3_TRAP + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   *  Web service message channel profile.
                   */
                  {
                    itemId : 'addWebServiceProfileButton',
                    text : QDesk.util.EnumUtils.getMessageChannelName(
                        QDesk.enums.message.MessageChannel.WEB_SERVICE ),
                    iconCls : QDesk.enums.message.MessageChannel.WEB_SERVICE,
                    qdRequiresAnyPermissions : [ QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                    qdNotAuthorizedIconCls : QDesk.enums.message.MessageChannel.WEB_SERVICE + '_NAUTH'
                  }
                ]
              }
            },
            {
              xtype : 'button',
              itemId : 'deleteFolderOrProfileButton',
              scale : 'small',
              iconCls : 'deleteFolderOrProfile',
              // no tooltip, it is set dynamically based on the selection (folder / profile)
              disabled : true,
              qdRequiresAnyPermissions : [
                QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_FLD_DELETE,
                QDesk.enums.security.Permission.MSG_CHANNEL_PROFILE_DELETE
              ],
              qdNotAuthorizedIconCls : 'deleteFolderOrProfileNAUTH'
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );
  }
} );
